@@ -528,35 +528,42 @@ class MainWindow(Gtk.Window):
 
         return False
 
-    def _update_page_information(self):
+    def _update_page_information(self) -> None:
         """ Updates the window with information that can be gathered
         even when the page pixbuf(s) aren't ready yet. """
 
         page_number = self.imagehandler.get_current_page()
         if not page_number:
             return
-        if self.displayed_double():
-            number_of_pages = 2
-            left_filename, right_filename = self.imagehandler.get_page_filename(double=True)
-            left_filesize, right_filesize = self.imagehandler.get_page_filesize(double=True)
+        double = self.displayed_double()
+
+        def make_status(info):
+            if not isinstance(info, tuple):
+                return info
             if self.is_manga_mode:
-                left_filename, right_filename = right_filename, left_filename
-                left_filesize, right_filesize = right_filesize, left_filesize
-            filename = left_filename + ', ' + right_filename
-            filesize = left_filesize + ', ' + right_filesize
-        else:
-            number_of_pages = 1
-            filename = self.imagehandler.get_page_filename()
-            filesize = self.imagehandler.get_page_filesize()
+                info = reversed(info)
+            return ", ".join(info)
+
+        filename = make_status(self.imagehandler.get_page_filename(double=double))
+        filesize = make_status(self.imagehandler.get_page_filesize(double=double))
         self.statusbar.set_page_number(page_number,
                                        self.imagehandler.get_number_of_pages(),
-                                       number_of_pages)
+                                       2 if double else 1)
         self.statusbar.set_filename(filename)
         self.statusbar.set_root(self.filehandler.get_base_filename())
         self.statusbar.set_filesize(filesize)
         self.statusbar.update()
         self.update_title()
 
+    def update_icon(self, default=False):
+        if (self.filehandler.archive_type is not None
+            and prefs['archive thumbnail as icon']):
+            pixbuf = self.imagehandler.get_thumbnail(1, 48, 48)
+            pixbuf = self.enhancer.enhance(pixbuf)
+            self.set_icon(pixbuf)
+        elif (default):
+            self.set_icon_list(icons.mcomix_icons())
+
     def _page_available(self, page):
         """ Called whenever a new page is ready for displaying. """
         # Refresh display when currently opened page becomes available.
@@ -567,11 +574,8 @@ class MainWindow(Gtk.Window):
             self._update_page_information()
 
         # Use first page as application icon when opening archives.
-        if (page == 1
-            and self.filehandler.archive_type is not None
-            and prefs['archive thumbnail as icon']):
-            pixbuf = self.imagehandler.get_thumbnail(page, 48, 48)
-            self.set_icon(pixbuf)
+        if page == 1:
+            self.update_icon(False)
 
     def _on_file_opened(self):
         self.uimanager.set_sensitivities()
@@ -745,6 +749,11 @@ class MainWindow(Gtk.Window):
         # as we'll be receiving a window state
         # change or resize event.
 
+    def change_invert_color(self, toggleaction):
+        prefs['invert color'] = not self.enhancer.invert_color
+        self.enhancer.invert_color = prefs['invert color']
+        self.enhancer.signal_update()
+
     def change_zoom_mode(self, radioaction=None, *args):
         if radioaction:
             prefs['zoom mode'] = radioaction.get_current_value()
@@ -955,7 +964,7 @@ class MainWindow(Gtk.Window):
         if self.slideshow.is_running():
             title = '[%s] %s' % (_('SLIDESHOW'), title)
 
-        self.set_title(title)
+        self.set_title(i18n.to_display_string(title))
 
     def set_bg_colour(self, colour):
         """Set the background colour to <colour>. Colour is a sequence in the
